import 'dart:io' show Platform;

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';

class WebViewDefaultApp extends StatefulWidget {
  final String redirectUrl;
  const WebViewDefaultApp({Key? key, required this.redirectUrl,required this.controller})
      : super(key: key);
  final WebViewController controller;
  @override
  State<WebViewDefaultApp> createState() => _WebViewDefaultAppState();
}

class _WebViewDefaultAppState extends State<WebViewDefaultApp> {
  String? loginId;
  // String? sessionId;
  var loadingPercentage = 0;
  bool showContent = false;
  bool isLoaded = false;

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();

    widget.controller
      ..setNavigationDelegate(
        NavigationDelegate(
          onPageStarted: (url) {
            print(url);
            // setState(() {
            //   loadingPercentage = 0;
            // });
          },
          onProgress: (progress) {

            // setState(() {
            //   loadingPercentage = progress;
            // });
          },
          onPageFinished: (url) {
            print(url);
            // setState(() {
            //   loadingPercentage = 100;
            // });
          },
          onNavigationRequest: (navigation) {
            final host = Uri.parse(navigation.url).host;
            if (host.contains('https://xyz.zyz')) {

              getSessionID(loginId!);

              return NavigationDecision.prevent;
            }
            return NavigationDecision.navigate;
          },
        ),
      )
      ..setJavaScriptMode(JavaScriptMode.unrestricted)..addJavaScriptChannel(
      'LOGINCHALLENGE',
      onMessageReceived: (message) async {
        print(message.message);
        if (message.message == 'loginSuccess') {
          CircularProgressIndicator();
          print('javascript----------');
          String sessionId = await getSessionID(loginId!);
          submitDatas('${ConscentInitializer.mClientId}',
              '${ConscentInitializer.mContentId}', sessionId);
        }
      },
    );
  }

  @override
  void dispose() {
    super.dispose();
    ConscentMethods().pageViewEvent(0, 0);
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print("WebViewDefaultApp loginId.toString()  ${loginId.toString()}");
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      const CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }



  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : const Padding(
            padding: EdgeInsets.all(8.0),
          );
  }


  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        WebViewWidget(
          controller: widget.controller..loadRequest(Uri.parse(widget.redirectUrl)),
        )
      ],
    );
  }
}
