import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:io' show Platform;
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';
import 'constants.dart';

class WebViewApp extends StatefulWidget {
  const WebViewApp({super.key,required this.controller});

  final WebViewController controller;

  @override
  State<WebViewApp> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewApp> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  var loadingPercentage = 0;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
    widget.controller
      ..setNavigationDelegate(
        NavigationDelegate(
          onPageStarted: (url) {
            print(url);
            // setState(() {
            //   loadingPercentage = 0;
            // });
          },
          onProgress: (progress) {

            // setState(() {
            //   loadingPercentage = progress;
            // });
          },
          onPageFinished: (url) {
            print(url);
            // setState(() {
            //   loadingPercentage = 100;
            // });
          },
          onNavigationRequest: (navigation) {
            final host = Uri.parse(navigation.url).host;
            if (host.contains('https://xyz.zyz')) {

              getSessionID();

              return NavigationDecision.prevent;
            }
            return NavigationDecision.navigate;
          },
        ),
      )
      ..setJavaScriptMode(JavaScriptMode.unrestricted)..addJavaScriptChannel(
      'LOGINCHALLENGE',
      onMessageReceived: (message) async {
        print(message.message);
        if (message.message == 'loginSuccess') {
          CircularProgressIndicator();
          print('javascript----------');
          String sessionId = await getSessionID();
          submitDatas('${ConscentInitializer.mClientId}',
              '${ConscentInitializer.mContentId}', sessionId);
        }
      },
    );
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print("WebViewApp loginId.toString() ${loginId.toString()}");
    getSessionID();
    setState(() {}
    );
  }

  Future<String> getSessionID() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('WebViewApp sessionId = ${prefs.getString('sessionId')}');
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      print("WebViewApp loginChallengeget.toJson() ${loginChallengeget.toJson()} ");
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('WebViewApp sessionId = $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      var responseString = response.body;

      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }



  // Home

  Widget homeBody() {
    return !isLoaded
        ? const CircularProgressIndicator()
        : Padding(
            padding: const EdgeInsets.all(8.0),
          );
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        WebViewWidget(
          controller: widget.controller..loadRequest(Uri.parse('${APIMode.SERVICE_BASE_URL}/overlay?clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId')),
        )
      ],
    );
  }

  //home

  // ... to here.

 
}
